@@ -112,6 +112,15 @@ typedef enum {
     VIR_NODE_DEV_CAP_FLAG_CSS_MDEV                  = (1 << 0),
 } virNodeDevCCWCapFlags;
 
+typedef enum {
+    VIR_NODE_DEV_CCW_STATE_OFFLINE = 0,
+    VIR_NODE_DEV_CCW_STATE_ONLINE,
+
+    VIR_NODE_DEV_CCW_STATE_LAST
+} virNodeDevCCWStateType;
+
+VIR_ENUM_DECL(virNodeDevCCWState);
+
 typedef enum {
     VIR_NODE_DEV_CAP_FLAG_AP_MATRIX_MDEV            = (1 << 0),
 } virNodeDevAPMatrixCapFlags;
@@ -279,6 +288,7 @@ struct _virNodeDevCapCCW {
     virMediatedDeviceType **mdev_types;
     size_t nmdev_types;
     virCCWDeviceAddress *channel_dev_addr;
+    virNodeDevCCWStateType state;
 };
 
 typedef struct _virNodeDevCapVDPA virNodeDevCapVDPA;
@@ -470,3 +480,6 @@ virNodeDeviceUpdateCaps(virNodeDeviceDef *def);
 int
 virNodeDeviceCapsListExport(virNodeDeviceDef *def,
                             virNodeDevCapType **list);
+
+void
+virNodeDeviceSyncMdevActiveConfig(virNodeDeviceDef *def);
