@@ -448,7 +448,8 @@ virCPUarmGetMap(void)
 static int
 virCPUarmUpdate(virCPUDef *guest,
                 const virCPUDef *host,
-                bool relative)
+                bool relative,
+                virCPUFeaturePolicy removedPolicy G_GNUC_UNUSED)
 {
     g_autoptr(virCPUDef) updated = virCPUDefCopyWithoutModel(guest);
 
