@@ -32,6 +32,7 @@
 #include "virfile.h"
 #include "virdevmapper.h"
 #include "virglibutil.h"
+#include "virhostdev.h"
 
 #define VIR_FROM_THIS VIR_FROM_QEMU
 
@@ -231,7 +232,14 @@ int
 qemuSetupImageCgroup(virDomainObj *vm,
                      virStorageSource *src)
 {
-    return qemuSetupImageCgroupInternal(vm, src, false);
+    if (qemuSetupImageCgroupInternal(vm, src, false) < 0)
+        return -1;
+
+    if (src->dataFileStore &&
+        qemuSetupImageCgroupInternal(vm, src->dataFileStore, false) < 0)
+        return -1;
+
+    return 0;
 }
 
 
@@ -320,6 +328,10 @@ qemuSetupImageChainCgroup(virDomainObj *vm,
         if (qemuSetupImageCgroupInternal(vm, next, forceReadonly) < 0)
             return -1;
 
+        if (next->dataFileStore &&
+            qemuSetupImageCgroupInternal(vm, next->dataFileStore, forceReadonly) < 0)
+            return -1;
+
         /* setup only the top level image for read-write */
         forceReadonly = true;
     }
@@ -481,7 +493,7 @@ qemuSetupHostdevCgroup(virDomainObj *vm,
         return -1;
     }
 
-    if (qemuHostdevNeedsVFIO(dev) &&
+    if (virHostdevNeedsVFIO(dev) &&
         qemuCgroupAllowDevicePath(vm, QEMU_DEV_VFIO,
                                   VIR_CGROUP_DEVICE_RW, false) < 0) {
         return -1;
@@ -530,7 +542,7 @@ qemuTeardownHostdevCgroup(virDomainObj *vm,
         return -1;
     }
 
-    if (qemuHostdevNeedsVFIO(dev) &&
+    if (virHostdevNeedsVFIO(dev) &&
         !qemuDomainNeedsVFIO(vm->def) &&
         qemuCgroupDenyDevicePath(vm, QEMU_DEV_VFIO,
                                  VIR_CGROUP_DEVICE_RWM, false) < 0) {
@@ -845,10 +857,21 @@ qemuSetupDevicesCgroup(virDomainObj *vm)
             return -1;
     }
 
-    if (vm->def->sec &&
-        vm->def->sec->sectype == VIR_DOMAIN_LAUNCH_SECURITY_SEV &&
-        qemuSetupSEVCgroup(vm) < 0)
-        return -1;
+    if (vm->def->sec) {
+        switch (vm->def->sec->sectype) {
+        case VIR_DOMAIN_LAUNCH_SECURITY_SEV:
+        case VIR_DOMAIN_LAUNCH_SECURITY_SEV_SNP:
+            if (qemuSetupSEVCgroup(vm) < 0)
+                return -1;
+            break;
+        case VIR_DOMAIN_LAUNCH_SECURITY_PV:
+            break;
+        case VIR_DOMAIN_LAUNCH_SECURITY_NONE:
+        case VIR_DOMAIN_LAUNCH_SECURITY_LAST:
+            virReportEnumRangeError(virDomainLaunchSecurity, vm->def->sec->sectype);
+            return -1;
+        }
+    }
 
     return 0;
 }
