@@ -783,6 +783,15 @@ qemuDomainPstoreDefPostParse(virDomainPstoreDef *pstore,
 }
 
 
+static bool
+qemuDomainNeedsIOMMUWithEIM(const virDomainDef *def)
+{
+    return ARCH_IS_X86(def->os.arch) &&
+           virDomainDefGetVcpusMax(def) > QEMU_MAX_VCPUS_WITHOUT_EIM &&
+           qemuDomainIsQ35(def);
+}
+
+
 static int
 qemuDomainIOMMUDefPostParse(virDomainIOMMUDef *iommu,
                             const virDomainDef *def,
@@ -793,9 +802,7 @@ qemuDomainIOMMUDefPostParse(virDomainIOMMUDef *iommu,
      * (EIM) is not explicitly turned off, let's enable it. If we didn't then
      * guest will have troubles with interrupts. */
     if (parseFlags & VIR_DOMAIN_DEF_PARSE_ABI_UPDATE &&
-        ARCH_IS_X86(def->os.arch) &&
-        virDomainDefGetVcpusMax(def) > QEMU_MAX_VCPUS_WITHOUT_EIM &&
-        qemuDomainIsQ35(def) &&
+        qemuDomainNeedsIOMMUWithEIM(def) &&
         iommu && iommu->model == VIR_DOMAIN_IOMMU_MODEL_INTEL) {
 
         /* eim requires intremap. */
@@ -1547,6 +1554,17 @@ qemuDomainDefEnableDefaultFeatures(virDomainDef *def,
          * capabilities, we still want to enable this */
         def->features[VIR_DOMAIN_FEATURE_GIC] = VIR_TRISTATE_SWITCH_ON;
     }
+
+    /* IOMMU with intremap requires split I/O APIC. But it may happen that
+     * domain already has IOMMU without inremap. This will be fixed in
+     * qemuDomainIOMMUDefPostParse() but there domain definition can't be
+     * modified so change it now. */
+    if (def->iommu &&
+        (def->iommu->intremap == VIR_TRISTATE_SWITCH_ON ||
+         qemuDomainNeedsIOMMUWithEIM(def)) &&
+        def->features[VIR_DOMAIN_FEATURE_IOAPIC] == VIR_DOMAIN_IOAPIC_NONE) {
+        def->features[VIR_DOMAIN_FEATURE_IOAPIC] = VIR_DOMAIN_IOAPIC_QEMU;
+    }
 }
 
 
@@ -1636,7 +1654,7 @@ qemuDomainDefVcpusPostParse(virDomainDef *def)
             /* they can be ordered only at the beginning */
             if (prevvcpu->hotpluggable == VIR_TRISTATE_BOOL_YES) {
                 virReportError(VIR_ERR_CONFIG_UNSUPPORTED, "%s",
-                               _("online non-hotpluggable vcpus need to be ordered prior to hotplugable vcpus"));
+                               _("online non-hotpluggable vcpus need to be ordered prior to hotpluggable vcpus"));
                 return -1;
             }
 
