@@ -82,7 +82,8 @@ virNetDevTapReattachBridge(const char *tapname,
                            const virNetDevVlan *virtVlan,
                            virTristateBool isolatedPort,
                            unsigned int mtu,
-                           unsigned int *actualMTU)
+                           unsigned int *actualMTU,
+                           bool force)
     ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(3)
     G_GNUC_WARN_UNUSED_RESULT;
 
