@@ -25,5 +25,5 @@ double virRandom(void);
 uint32_t virRandomInt(uint32_t max);
 int virRandomBytes(unsigned char *buf, size_t buflen)
     ATTRIBUTE_NONNULL(1) G_GNUC_WARN_UNUSED_RESULT G_NO_INLINE;
-int virRandomGenerateWWN(char **wwn, const char *virt_type) G_NO_INLINE;
+int virRandomGenerateWWN(char **wwn, const char *virt_type);
 char *virRandomToken(size_t len);
