@@ -1078,12 +1078,10 @@ void
 virStringListRemoveDuplicates(char ***list)
 {
     size_t len = g_strv_length(*list);
-    char **unique;
+    char **unique = g_new0(char *, len + 1);
     size_t n = 0;
     size_t i;
 
-    unique = g_malloc0_n(len + 1, sizeof(char *));
-
     for (i = 0; i < len; i++) {
         if (n > 0 && STREQ_NULLABLE(unique[n - 1], (*list)[i]))
             g_free((*list)[i]);
