@@ -263,7 +263,7 @@ virSysinfoParsePPCSystem(const char *base, virSysinfoSystemDef **sysdef)
     return ret;
 }
 
-static int
+static void
 virSysinfoParsePPCProcessor(const char *base, virSysinfoDef *ret)
 {
     const char *cur;
@@ -303,8 +303,6 @@ virSysinfoParsePPCProcessor(const char *base, virSysinfoDef *ret)
         }
 
     }
-
-    return 0;
 }
 
 /* virSysinfoRead for PowerPC
@@ -325,8 +323,7 @@ virSysinfoReadPPC(void)
 
     ret->nprocessor = 0;
     ret->processor = NULL;
-    if (virSysinfoParsePPCProcessor(outbuf, ret) < 0)
-        return NULL;
+    virSysinfoParsePPCProcessor(outbuf, ret);
 
     if (virSysinfoParsePPCSystem(outbuf, &ret->system) < 0)
         return NULL;
@@ -383,7 +380,7 @@ virSysinfoParseARMSystem(const char *base, virSysinfoSystemDef **sysdef)
     return ret;
 }
 
-static int
+static void
 virSysinfoParseARMProcessor(const char *base, virSysinfoDef *ret)
 {
     const char *cur;
@@ -393,7 +390,7 @@ virSysinfoParseARMProcessor(const char *base, virSysinfoDef *ret)
 
     if (!(tmp_base = strstr(base, "model name")) &&
         !(tmp_base = strstr(base, "Processor")))
-        return 0;
+        return;
 
     eol = strchr(tmp_base, '\n');
     cur = strchr(tmp_base, ':') + 1;
@@ -420,7 +417,7 @@ virSysinfoParseARMProcessor(const char *base, virSysinfoDef *ret)
     }
 
     VIR_FREE(processor_type);
-    return 0;
+    return;
 }
 
 /* virSysinfoRead for ARMv7
@@ -451,8 +448,7 @@ virSysinfoReadARM(void)
 
     ret->nprocessor = 0;
     ret->processor = NULL;
-    if (virSysinfoParseARMProcessor(outbuf, ret) < 0)
-        return NULL;
+    virSysinfoParseARMProcessor(outbuf, ret);
 
     if (virSysinfoParseARMSystem(outbuf, &ret->system) < 0)
         return NULL;
@@ -753,7 +749,7 @@ virSysinfoParseX86System(const char *base, virSysinfoSystemDef **sysdef)
     return ret;
 }
 
-static int
+static void
 virSysinfoParseX86BaseBoard(const char *base,
                             virSysinfoBaseBoardDef **baseBoard,
                             size_t *nbaseBoard)
@@ -827,7 +823,6 @@ virSysinfoParseX86BaseBoard(const char *base,
 
     *nbaseBoard = nboards;
     *baseBoard = g_steal_pointer(&boards);
-    return 0;
 }
 
 
@@ -895,13 +890,13 @@ virSysinfoParseX86Chassis(const char *base,
 
 
 static int
-virSysinfoDMIDecodeOEMString(size_t i,
+virSysinfoDMIDecodeOEMString(unsigned int idx,
                              char **str)
 {
     g_autofree char *err = NULL;
     g_autoptr(virCommand) cmd = virCommandNewArgList(DMIDECODE, "--dump",
                                                      "--oem-string", NULL);
-    virCommandAddArgFormat(cmd, "%zu", i);
+    virCommandAddArgFormat(cmd, "%u", idx);
     virCommandSetOutputBuffer(cmd, str);
     virCommandSetErrorBuffer(cmd, &err);
 
@@ -910,11 +905,23 @@ virSysinfoDMIDecodeOEMString(size_t i,
 
     /* Unfortunately, dmidecode returns 0 even if OEM String index is out
      * of bounds, but it prints an error message in that case. Check stderr
-     * and return success/failure accordingly. */
-
-    if (err && *err != '\0')
+     * and return success/failure accordingly.
+     * To make matters worse, if there are two or more 'OEM String'
+     * sections then:
+     *
+     * a) we have no way of distinguishing them as dmidecode prints
+     *    strings from all sections,
+     * b) if one section contains a valid string, but the other doesn't,
+     *    then stdout contains the valid string and stderr contains the
+     *    error "No OEM string number X*.
+     *
+     * Let's just hope there is not many systems like that.
+     */
+    if ((!*str || **str == '\0') && err && *err != '\0')
         return -1;
 
+    virStringTrimOptionalNewline(*str);
+
     return 0;
 }
 
@@ -924,7 +931,6 @@ virSysinfoParseOEMStrings(const char *base,
                           virSysinfoOEMStringsDef **stringsRet)
 {
     virSysinfoOEMStringsDef *strings = NULL;
-    size_t i = 1;
     int ret = -1;
     const char *cur;
 
@@ -934,6 +940,8 @@ virSysinfoParseOEMStrings(const char *base,
     strings = g_new0(virSysinfoOEMStringsDef, 1);
 
     while ((cur = strstr(cur, "String "))) {
+        char *collon = NULL;
+        unsigned int idx = 0;
         char *eol;
 
         cur += 7;
@@ -944,8 +952,13 @@ virSysinfoParseOEMStrings(const char *base,
             goto cleanup;
         }
 
-        while (g_ascii_isdigit(*cur))
-            cur++;
+        if (virStrToLong_ui(cur, &collon, 10, &idx) < 0) {
+            virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
+                           _("Malformed output of dmidecode"));
+            goto cleanup;
+        }
+
+        cur = collon;
 
         if (*cur != ':') {
             virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
@@ -968,7 +981,7 @@ virSysinfoParseOEMStrings(const char *base,
         if (memchr(cur, '.', eol - cur)) {
             char *str;
 
-            if (virSysinfoDMIDecodeOEMString(i, &str) < 0)
+            if (virSysinfoDMIDecodeOEMString(idx, &str) < 0)
                 goto cleanup;
 
             strings->values[strings->nvalues - 1] = g_steal_pointer(&str);
@@ -976,7 +989,6 @@ virSysinfoParseOEMStrings(const char *base,
             strings->values[strings->nvalues - 1] = g_strndup(cur, eol - cur);
         }
 
-        i++;
         cur = eol;
     }
 
@@ -989,7 +1001,7 @@ virSysinfoParseOEMStrings(const char *base,
 }
 
 
-static int
+static void
 virSysinfoParseX86Processor(const char *base, virSysinfoDef *ret)
 {
     const char *cur, *tmp_base;
@@ -1085,11 +1097,9 @@ virSysinfoParseX86Processor(const char *base, virSysinfoDef *ret)
 
         base += strlen("Processor Information");
     }
-
-    return 0;
 }
 
-static int
+static void
 virSysinfoParseX86Memory(const char *base, virSysinfoDef *ret)
 {
     const char *cur, *tmp_base;
@@ -1180,8 +1190,6 @@ virSysinfoParseX86Memory(const char *base, virSysinfoDef *ret)
     next:
         base += strlen("Memory Device");
     }
-
-    return 0;
 }
 
 virSysinfoDef *
@@ -1206,8 +1214,7 @@ virSysinfoReadDMI(void)
     if (virSysinfoParseX86System(outbuf, &ret->system) < 0)
         return NULL;
 
-    if (virSysinfoParseX86BaseBoard(outbuf, &ret->baseBoard, &ret->nbaseBoard) < 0)
-        return NULL;
+    virSysinfoParseX86BaseBoard(outbuf, &ret->baseBoard, &ret->nbaseBoard);
 
     if (virSysinfoParseX86Chassis(outbuf, &ret->chassis) < 0)
         return NULL;
@@ -1217,13 +1224,11 @@ virSysinfoReadDMI(void)
 
     ret->nprocessor = 0;
     ret->processor = NULL;
-    if (virSysinfoParseX86Processor(outbuf, ret) < 0)
-        return NULL;
+    virSysinfoParseX86Processor(outbuf, ret);
 
     ret->nmemory = 0;
     ret->memory = NULL;
-    if (virSysinfoParseX86Memory(outbuf, ret) < 0)
-        return NULL;
+    virSysinfoParseX86Memory(outbuf, ret);
 
     return g_steal_pointer(&ret);
 }
