@@ -31,6 +31,10 @@ bool virTPMHasSwtpm(void);
 typedef enum {
     VIR_TPM_SWTPM_FEATURE_CMDARG_PWD_FD,
     VIR_TPM_SWTPM_FEATURE_CMDARG_MIGRATION,
+    VIR_TPM_SWTPM_FEATURE_NVRAM_BACKEND_DIR,
+    VIR_TPM_SWTPM_FEATURE_NVRAM_BACKEND_FILE,
+    VIR_TPM_SWTPM_FEATURE_CMDARG_PRINT_INFO,
+    VIR_TPM_SWTPM_FEATURE_TPMSTATE_OPT_LOCK,
 
     VIR_TPM_SWTPM_FEATURE_LAST
 } virTPMSwtpmFeature;
@@ -42,6 +46,7 @@ typedef enum {
     VIR_TPM_SWTPM_SETUP_FEATURE_CMDARG_RECONFIGURE_PCR_BANKS,
     VIR_TPM_SWTPM_SETUP_FEATURE_TPM_1_2,
     VIR_TPM_SWTPM_SETUP_FEATURE_TPM_2_0,
+    VIR_TPM_SWTPM_SETUP_FEATURE_CMDARG_PROFILE,
 
     VIR_TPM_SWTPM_SETUP_FEATURE_LAST
 } virTPMSwtpmSetupFeature;
