@@ -16,8 +16,7 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVIRT_VIRVSOCK_H
-# define LIBVIRT_VIRVSOCK_H
+#pragma once
 
 int
 virVsockSetGuestCid(int fd,
@@ -26,4 +25,3 @@ virVsockSetGuestCid(int fd,
 int
 virVsockAcquireGuestCid(int fd,
                         unsigned int *guest_cid);
-#endif /* LIBVIRT_VIRVSOCK_H */
