@@ -236,7 +236,7 @@ cpuTestGuestCPU(const void *arg)
         goto cleanup;
     }
 
-    if (virCPUUpdate(host->arch, cpu, host) < 0 ||
+    if (virCPUUpdate(host->arch, cpu, host, VIR_CPU_FEATURE_DISABLE) < 0 ||
         virCPUTranslate(host->arch, cpu, data->models) < 0) {
         ret = -1;
         goto cleanup;
@@ -363,7 +363,7 @@ cpuTestUpdate(const void *arg)
     if (!(migHost = virCPUCopyMigratable(data->arch, host)))
         return -1;
 
-    if (virCPUUpdate(host->arch, cpu, migHost) < 0)
+    if (virCPUUpdate(host->arch, cpu, migHost, VIR_CPU_FEATURE_DISABLE) < 0)
         return -1;
 
     result = g_strdup_printf("%s+%s", data->host, data->name);
@@ -823,7 +823,8 @@ cpuTestUpdateLive(const void *arg)
         }
 
         virDomainCapsCPUModelsAdd(models, expected->model,
-                                  usable, blockers, false, expected->vendor);
+                                  usable, blockers, false,
+                                  expected->vendor, NULL);
 
         cpu->fallback = VIR_CPU_FALLBACK_ALLOW;
         ignore_value(virCPUTranslate(data->arch, cpu, models));
@@ -902,7 +903,7 @@ cpuTestInitModels(const char **list)
     for (model = list; *model; model++) {
         virDomainCapsCPUModelsAdd(cpus, *model,
                                   VIR_DOMCAPS_CPU_USABLE_UNKNOWN,
-                                  NULL, false, NULL);
+                                  NULL, false, NULL, NULL);
     }
 
     return cpus;
