@@ -107,8 +107,7 @@ testNWFilterEBIPTablesAllTeardown(const void *opaque G_GNUC_UNUSED)
 
     actual = virBufferContentAndReset(&buf);
 
-    if (STRNEQ_NULLABLE(actual, expected)) {
-        virTestDifference(stderr, expected, actual);
+    if (virTestCompareToString(actual, expected) < 0) {
         return -1;
     }
 
@@ -169,8 +168,7 @@ testNWFilterEBIPTablesTearOldRules(const void *opaque G_GNUC_UNUSED)
 
     actual = virBufferContentAndReset(&buf);
 
-    if (STRNEQ_NULLABLE(actual, expected)) {
-        virTestDifference(stderr, expected, actual);
+    if (virTestCompareToString(expected, actual) < 0) {
         return -1;
     }
 
@@ -209,8 +207,7 @@ testNWFilterEBIPTablesRemoveBasicRules(const void *opaque G_GNUC_UNUSED)
 
     actual = virBufferContentAndReset(&buf);
 
-    if (STRNEQ_NULLABLE(actual, expected)) {
-        virTestDifference(stderr, expected, actual);
+    if (virTestCompareToString(expected, actual) < 0) {
         return -1;
     }
 
@@ -234,8 +231,7 @@ testNWFilterEBIPTablesTearNewRules(const void *opaque G_GNUC_UNUSED)
 
     actual = virBufferContentAndReset(&buf);
 
-    if (STRNEQ_NULLABLE(actual, expected)) {
-        virTestDifference(stderr, expected, actual);
+    if (virTestCompareToString(expected, actual) < 0) {
         return -1;
     }
 
@@ -297,8 +293,7 @@ testNWFilterEBIPTablesApplyBasicRules(const void *opaque G_GNUC_UNUSED)
 
     actual = virBufferContentAndReset(&buf);
 
-    if (STRNEQ_NULLABLE(actual, expected)) {
-        virTestDifference(stderr, expected, actual);
+    if (virTestCompareToString(expected, actual) < 0) {
         return -1;
     }
 
@@ -378,8 +373,7 @@ testNWFilterEBIPTablesApplyDHCPOnlyRules(const void *opaque G_GNUC_UNUSED)
 
     actual = virBufferContentAndReset(&buf);
 
-    if (STRNEQ_NULLABLE(actual, expected)) {
-        virTestDifference(stderr, expected, actual);
+    if (virTestCompareToString(expected, actual) < 0) {
         return -1;
     }
 
@@ -442,8 +436,7 @@ testNWFilterEBIPTablesApplyDropAllRules(const void *opaque G_GNUC_UNUSED)
 
     actual = virBufferContentAndReset(&buf);
 
-    if (STRNEQ_NULLABLE(actual, expected)) {
-        virTestDifference(stderr, expected, actual);
+    if (virTestCompareToString(expected, actual) < 0) {
         return -1;
     }
 
