@@ -39,10 +39,19 @@ struct _testQemuData {
     const char *prefix;
     const char *version;
     const char *archName;
+    const char *variant;
     const char *suffix;
     int ret;
 };
 
+bool isHVF = false;
+
+bool
+virQEMUCapsProbeHVF(virQEMUCaps *qemuCaps G_GNUC_UNUSED)
+{
+    return isHVF;
+}
+
 
 static int
 testQemuDataInit(testQemuData *data)
@@ -78,17 +87,19 @@ testQemuCaps(const void *opaque)
     unsigned int fakeMicrocodeVersion = 0;
     const char *p;
 
-    repliesFile = g_strdup_printf("%s/%s_%s.%s.%s",
+    repliesFile = g_strdup_printf("%s/%s_%s_%s%s.%s",
                                   data->inputDir, data->prefix, data->version,
-                                  data->archName, data->suffix);
-    capsFile = g_strdup_printf("%s/%s_%s.%s.xml",
+                                  data->archName, data->variant, data->suffix);
+    capsFile = g_strdup_printf("%s/%s_%s_%s%s.xml",
                                data->outputDir, data->prefix, data->version,
-                               data->archName);
+                               data->archName, data->variant);
 
     if (!(mon = qemuMonitorTestNewFromFileFull(repliesFile, &data->driver, NULL,
                                                NULL)))
         return -1;
 
+    isHVF = STREQ(data->variant, "+hvf");
+
     if (qemuProcessQMPInitMonitor(qemuMonitorTestGetMonitor(mon)) < 0)
         return -1;
 
@@ -100,7 +111,8 @@ testQemuCaps(const void *opaque)
     if (virQEMUCapsInitQMPMonitor(capsActual, qemuMonitorTestGetMonitor(mon)) < 0)
         return -1;
 
-    if (virQEMUCapsGet(capsActual, QEMU_CAPS_KVM)) {
+    if (virQEMUCapsHaveAccel(capsActual) &&
+        virQEMUCapsGet(capsActual, QEMU_CAPS_TCG)) {
         qemuMonitorResetCommandID(qemuMonitorTestGetMonitor(mon));
 
         if (qemuProcessQMPInitMonitor(qemuMonitorTestGetMonitor(mon)) < 0)
@@ -142,9 +154,9 @@ testQemuCapsCopy(const void *opaque)
     g_autoptr(virQEMUCaps) copy = NULL;
     g_autofree char *actual = NULL;
 
-    capsFile = g_strdup_printf("%s/%s_%s.%s.xml",
+    capsFile = g_strdup_printf("%s/%s_%s_%s%s.xml",
                                data->outputDir, data->prefix, data->version,
-                               data->archName);
+                               data->archName, data->variant);
 
     if (!(orig = qemuTestParseCapabilitiesArch(
               virArchFromString(data->archName), capsFile)))
@@ -167,6 +179,7 @@ doCapsTest(const char *inputDir,
            const char *prefix,
            const char *version,
            const char *archName,
+           const char *variant,
            const char *suffix,
            void *opaque)
 {
@@ -181,6 +194,7 @@ doCapsTest(const char *inputDir,
     data->prefix = prefix;
     data->version = version;
     data->archName = archName;
+    data->variant = variant,
     data->suffix = suffix;
 
     if (virTestRun(title, testQemuCaps, data) < 0)
@@ -206,23 +220,7 @@ mymain(void)
     if (testQemuCapsIterate(".replies", doCapsTest, &data) < 0)
         return EXIT_FAILURE;
 
-    /*
-     * Run "tests/qemucapsprobe /path/to/qemu/binary >foo.replies"
-     * to generate updated or new *.replies data files.
-     *
-     * If you manually edit replies files you can run
-     * VIR_TEST_REGENERATE_OUTPUT=1 tests/qemucapabilitiesnumbering
-     * to fix the replies ids. The tool also allows for programmatic
-     * modification of the replies file.
-     *
-     * Once a replies file has been generated and tweaked if necessary,
-     * you can drop it into tests/qemucapabilitiesdata/ (with a sensible
-     * name - look at what's already there for inspiration) and test
-     * programs will automatically pick it up.
-     *
-     * To generate the corresponding output files after a new replies
-     * file has been added, run "VIR_TEST_REGENERATE_OUTPUT=1 ninja test".
-     */
+    /* See documentation in qemucapabilitiesdata/README.rst */
 
     testQemuDataReset(&data);
 
