@@ -61,6 +61,7 @@ typedef enum {
     FLAG_REAL_CAPS          = 1 << 2,
     FLAG_SLIRP_HELPER       = 1 << 3,
     FLAG_ALLOW_DUPLICATE_OUTPUT = 1 << 4, /* allow multiple tests with the same output file */
+    FLAG_ALLOW_MISSING_INPUT = 1 << 5,
 } testQemuInfoFlags;
 
 struct testQemuConf {
@@ -125,9 +126,6 @@ typedef struct _testQemuInfo testQemuInfo;
 void testQemuInfoFree(testQemuInfo *info);
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(testQemuInfo, testQemuInfoFree);
 
-virDomainXMLOption *testQemuXMLConfInit(void);
-
-
 virQEMUCaps *qemuTestParseCapabilitiesArch(virArch arch,
                                              const char *capsFile);
 virCPUDef *qemuTestGetCPUDef(qemuTestCPUDef d);
