@@ -577,18 +577,45 @@ test12b(const void *opaque G_GNUC_UNUSED)
 {
     g_autoptr(virBitmap) map = NULL;
 
-    if (!(map = virBitmapParseUnlimited("34,1023")))
+    if (!(map = virBitmapParseUnlimited("31,32,63,64,1023")))
         return -1;
 
-    if (checkBitmap(map, "34,1023", 1024) < 0)
+    if (checkBitmap(map, "31-32,63-64,1023", 1024) < 0)
         return -1;
 
-    virBitmapShrink(map, 35);
-    if (checkBitmap(map, "34", 35) < 0)
+    /* no shrink at full alloc */
+    virBitmapShrink(map, 1025);
+    if (checkBitmap(map, "31-32,63-64,1023", 1024) < 0)
         return -1;
 
-    virBitmapShrink(map, 34);
-    if (checkBitmap(map, "", 34) < 0)
+    /* shrink at the end */
+    virBitmapShrink(map, 1023);
+    if (checkBitmap(map, "31-32,63-64", 1023) < 0)
+        return -1;
+
+    /* extend back to see whether tail was cleared */
+    virBitmapSetBitExpand(map, 1022);
+    if (checkBitmap(map, "31-32,63-64,1022", 1023) < 0)
+        return -1;
+
+    virBitmapShrink(map, 64);
+    if (checkBitmap(map, "31-32,63", 64) < 0)
+        return -1;
+
+    virBitmapShrink(map, 65);
+    if (checkBitmap(map, "31-32,63", 64) < 0)
+        return -1;
+
+    virBitmapShrink(map, 63);
+    if (checkBitmap(map, "31-32", 63) < 0)
+        return -1;
+
+    virBitmapShrink(map, 32);
+    if (checkBitmap(map, "31", 32) < 0)
+        return -1;
+
+    virBitmapShrink(map, 31);
+    if (checkBitmap(map, "", 31) < 0)
         return -1;
 
     return 0;
@@ -705,6 +732,43 @@ test16(const void *opaque G_GNUC_UNUSED)
 }
 
 
+/* virBitmapParseUnlimitedAllowEmpty */
+static int
+test17(const void *opaque G_GNUC_UNUSED)
+{
+    g_autoptr(virBitmap) map1 = NULL;
+    g_autoptr(virBitmap) map2 = NULL;
+    g_autofree char *map1_str = NULL;
+    g_autofree char *map2_str = NULL;
+
+    if (!(map1 = virBitmapParseUnlimitedAllowEmpty(NULL))) {
+        fprintf(stderr, "Expected success, got failure\n");
+        return -1;
+    }
+
+    if (!(map2 = virBitmapParseUnlimitedAllowEmpty("    "))) {
+        fprintf(stderr, "Expected success, got failure\n");
+        return -1;
+    }
+
+    if (!virBitmapIsAllClear(map1) ||
+        !virBitmapIsAllClear(map2) ||
+        !virBitmapEqual(map1, map2)) {
+        fprintf(stderr, "empty maps should equal\n");
+        return -1;
+    }
+
+    if (!(map1_str = virBitmapFormat(map1)) ||
+        !(map2_str = virBitmapFormat(map2)) ||
+        STRNEQ(map1_str, map2_str)) {
+        fprintf(stderr, "maps don't equal after format to string\n");
+        return -1;
+    }
+
+    return 0;
+}
+
+
 #define TESTBINARYOP(A, B, RES, FUNC) \
     testBinaryOpData.a = A; \
     testBinaryOpData.b = B; \
@@ -781,6 +845,9 @@ mymain(void)
     if (virTestRun("test16", test16, NULL) < 0)
         ret = -1;
 
+    if (virTestRun("test17", test17, NULL) < 0)
+        ret = -1;
+
     return ret == 0 ? EXIT_SUCCESS : EXIT_FAILURE;
 }
 
