@@ -40,8 +40,7 @@ checkOutput(virBuffer *buf, const char *exp_cmd)
         return -1;
     }
 
-    if (STRNEQ(exp_cmd, actual_cmd)) {
-        virTestDifference(stderr, exp_cmd, actual_cmd);
+    if (virTestCompareToString(exp_cmd, actual_cmd) < 0) {
         return -1;
     }
 
