@@ -36,9 +36,9 @@
 
 static int (*real_access)(const char *path, int mode);
 static int (*real_open)(const char *path, int flags, ...);
-# ifdef __GLIBC__
+# if WITH___OPEN_2
 static int (*real___open_2)(const char *path, int flags);
-# endif /* ! __GLIBC__ */
+# endif /* ! WITH___OPEN_2 */
 static int (*real_close)(int fd);
 static DIR * (*real_opendir)(const char *name);
 static char *(*real_virFileCanonicalizePath)(const char *path);
@@ -945,9 +945,9 @@ init_syms(void)
 
     VIR_MOCK_REAL_INIT(access);
     VIR_MOCK_REAL_INIT(open);
-# ifdef __GLIBC__
+# if WITH___OPEN_2
     VIR_MOCK_REAL_INIT(__open_2);
-# endif /* ! __GLIBC__ */
+# endif /* WITH___OPEN_2 */
     VIR_MOCK_REAL_INIT(close);
 # if defined(__APPLE__) && defined(__x86_64__)
     VIR_MOCK_REAL_INIT_ALIASED(opendir, "opendir$INODE64");
@@ -1110,12 +1110,7 @@ open(const char *path, int flags, ...)
 }
 
 
-# ifdef __GLIBC__
-/* in some cases this function may not be present in headers, so we need
- * a declaration to silence the compiler */
-int
-__open_2(const char *path, int flags);
-
+# if WITH___OPEN_2
 int
 __open_2(const char *path, int flags)
 {
@@ -1139,7 +1134,7 @@ __open_2(const char *path, int flags)
 
     return ret;
 }
-# endif /* ! __GLIBC__ */
+# endif /* WITH___OPEN_2 */
 
 DIR *
 opendir(const char *path)
