@@ -203,6 +203,26 @@ testStorageChain(const void *args)
                           NULLSTR(virStorageFileFormatTypeToString(elt->format)),
                           virStorageNetProtocolTypeToString(elt->protocol),
                           NULLSTR(elt->nhosts ? elt->hosts[0].name : NULL));
+
+        if (elt->dataFileStore) {
+            g_autofree char *strippedPathDataFileRaw = virTestStablePath(elt->dataFileRaw);
+            g_autofree char *strippedPathDataFile = virTestStablePath(elt->dataFileStore->path);
+
+            virBufferAsprintf(&buf,
+                              "dataFileRaw: %s\n\n\n"
+                              "dataFileStoreSource:\n"
+                              "path: %s\n"
+                              "capacity: %lld\n"
+                              "encryption: %d\n"
+                              "type:%s\n"
+                              "format:%s\n",
+                              strippedPathDataFileRaw,
+                              strippedPathDataFile,
+                              elt->dataFileStore->capacity,
+                              !!elt->dataFileStore->encryption,
+                              NULLSTR(virStorageTypeToString(elt->dataFileStore->type)),
+                              NULLSTR(virStorageFileFormatTypeToString(elt->dataFileStore->format)));
+        }
     }
 
     virBufferTrim(&buf, "\n");
@@ -464,6 +484,16 @@ mymain(void)
 
     testCleanupImages();
 
+    /* qcow2 + datafile
+     * 1) qcow2 image with data file
+     * 2) qcow2 -> qcow2 backing image with data file */
+    TEST_CHAIN("qcow2-datafile",
+               abs_srcdir "/virstoragetestdata/images/datafile.qcow2",
+               VIR_STORAGE_FILE_QCOW2, EXP_PASS);
+    TEST_CHAIN("qcow2datafile-qcow2_qcow2-datafile",
+               abs_srcdir "/virstoragetestdata/images/qcow2datafile-datafile.qcow2",
+               VIR_STORAGE_FILE_QCOW2, EXP_PASS);
+
     /* Test various combinations of qcow2 images with missing 'backing_format' */
     TEST_CHAIN("qcow2-qcow2_qcow2-qcow2_qcow2-auto",
                abs_srcdir "/virstoragetestdata/images/qcow2_qcow2-qcow2_qcow2-auto.qcow2",
@@ -815,7 +845,7 @@ mymain(void)
                             "  <host name='example.org' port='1234'/>\n"
                             "</source>\n", 1);
 
-#ifdef WITH_YAJL
+#ifdef WITH_JSON
     TEST_BACKING_PARSE("json:", NULL);
     TEST_BACKING_PARSE("json:asdgsdfg", NULL);
     TEST_BACKING_PARSE("json:{}", NULL);
@@ -1192,7 +1222,7 @@ mymain(void)
                         "  <address domain='0x0000' bus='0x01' slot='0x00' function='0x0'/>\n"
                         "</source>\n");
 
-#endif /* WITH_YAJL */
+#endif /* WITH_JSON */
 
     return ret == 0 ? EXIT_SUCCESS : EXIT_FAILURE;
 }
