@@ -21,10 +21,10 @@
 #include <config.h>
 
 #include "virsh-completer-network.h"
+#include "virsh-util.h"
 #include "viralloc.h"
 #include "virsh-network.h"
 #include "virsh.h"
-#include "virstring.h"
 
 char **
 virshNetworkNameCompleter(vshControl *ctl,
@@ -60,7 +60,7 @@ virshNetworkNameCompleter(vshControl *ctl,
     ret = g_steal_pointer(&tmp);
 
     for (i = 0; i < nnets; i++)
-        virNetworkFree(nets[i]);
+        virshNetworkFree(nets[i]);
     g_free(nets);
     return ret;
 }
@@ -170,7 +170,7 @@ virshNetworkUUIDCompleter(vshControl *ctl,
 
  cleanup:
     for (i = 0; i < nnets; i++)
-        virNetworkFree(nets[i]);
+        virshNetworkFree(nets[i]);
     g_free(nets);
     return ret;
 }
@@ -183,7 +183,7 @@ virshNetworkDhcpMacCompleter(vshControl *ctl,
 {
     virshControl *priv = ctl->privData;
     virNetworkDHCPLeasePtr *leases = NULL;
-    virNetworkPtr network = NULL;
+    g_autoptr(virshNetwork) network = NULL;
     int nleases;
     size_t i = 0;
     char **ret = NULL;
@@ -215,6 +215,48 @@ virshNetworkDhcpMacCompleter(vshControl *ctl,
             virNetworkDHCPLeaseFree(leases[i]);
         VIR_FREE(leases);
     }
-    virNetworkFree(network);
+    return ret;
+}
+
+
+char **
+virshNetworkUpdateCommandCompleter(vshControl *ctl G_GNUC_UNUSED,
+                                   const vshCmd *cmd G_GNUC_UNUSED,
+                                   unsigned int flags)
+{
+    char **ret = NULL;
+    size_t i;
+
+    virCheckFlags(0, NULL);
+
+    ret = g_new0(char *, VIR_NETWORK_UPDATE_COMMAND_LAST + 1);
+
+    /* The first item in the enum is not accepted by virsh, But there's "add"
+     * which is accepted an is just an alias to "add-last". */
+    ret[0] = g_strdup("add");
+
+    for (i = 1; i < VIR_NETWORK_UPDATE_COMMAND_LAST; i++)
+        ret[i] = g_strdup(virshNetworkUpdateCommandTypeToString(i));
+
+    return ret;
+}
+
+
+char **
+virshNetworkUpdateSectionCompleter(vshControl *ctl G_GNUC_UNUSED,
+                                   const vshCmd *cmd G_GNUC_UNUSED,
+                                   unsigned int flags)
+{
+    char **ret = NULL;
+    size_t i;
+
+    virCheckFlags(0, NULL);
+
+    ret = g_new0(char *, VIR_NETWORK_SECTION_LAST);
+
+    /* The first item in the enum is not accepted by virsh. */
+    for (i = 1; i < VIR_NETWORK_SECTION_LAST; i++)
+        ret[i - 1] = g_strdup(virshNetworkSectionTypeToString(i));
+
     return ret;
 }
