@@ -49,6 +49,7 @@
 #define VIRSH_COMMON_OPT_POOL_OPTIONAL \
     {.name = "pool", \
      .type = VSH_OT_STRING, \
+     .positional = true, \
      .help = N_("pool name or uuid"), \
      .completer = virshStoragePoolNameCompleter, \
      .completer_flags = VIR_CONNECT_LIST_STORAGE_POOLS_ACTIVE, \
@@ -56,16 +57,18 @@
 
 #define VIRSH_COMMON_OPT_VOL_NAME(_helpstr) \
     {.name = "vol", \
-     .type = VSH_OT_DATA, \
-     .flags = VSH_OFLAG_REQ, \
+     .type = VSH_OT_STRING, \
+     .positional = true, \
+     .required = true, \
      .help = _helpstr, \
      .completer = virshStorageVolNameCompleter, \
     }
 
 #define VIRSH_COMMON_OPT_VOL_KEY(_helpstr) \
     {.name = "vol", \
-     .type = VSH_OT_DATA, \
-     .flags = VSH_OFLAG_REQ, \
+     .type = VSH_OT_STRING, \
+     .positional = true, \
+     .required = true, \
      .help = _helpstr, \
      .completer = virshStorageVolKeyCompleter, \
     }
@@ -89,11 +92,11 @@ virshCommandOptVolBy(vshControl *ctl, const vshCmd *cmd,
 
     virCheckFlags(VIRSH_BYUUID | VIRSH_BYNAME, NULL);
 
-    if (vshCommandOptStringReq(ctl, cmd, optname, &n) < 0)
+    if (vshCommandOptString(ctl, cmd, optname, &n) < 0)
         return NULL;
 
     if (pooloptname != NULL &&
-        vshCommandOptStringReq(ctl, cmd, pooloptname, &p) < 0)
+        vshCommandOptString(ctl, cmd, pooloptname, &p) < 0)
         return NULL;
 
     if (p) {
@@ -164,45 +167,46 @@ virshCommandOptVolBy(vshControl *ctl, const vshCmd *cmd,
 /*
  * "vol-create-as" command
  */
-static const vshCmdInfo info_vol_create_as[] = {
-    {.name = "help",
-     .data = N_("create a volume from a set of args")
-    },
-    {.name = "desc",
-     .data = N_("Create a vol.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_create_as = {
+    .help = N_("create a volume from a set of args"),
+    .desc = N_("Create a vol."),
 };
 
 static const vshCmdOptDef opts_vol_create_as[] = {
     VIRSH_COMMON_OPT_POOL_NAME,
     {.name = "name",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .completer = virshCompleteEmpty,
      .help = N_("name of the volume")
     },
     {.name = "capacity",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .completer = virshCompleteEmpty,
      .help = N_("size of the vol, as scaled integer (default bytes)")
     },
     {.name = "allocation",
      .type = VSH_OT_STRING,
+     .unwanted_positional = true,
      .completer = virshCompleteEmpty,
      .help = N_("initial allocation size, as scaled integer (default bytes)")
     },
     {.name = "format",
      .type = VSH_OT_STRING,
+     .unwanted_positional = true,
      .help = N_("file format type raw,bochs,qcow,qcow2,qed,vmdk")
     },
     {.name = "backing-vol",
      .type = VSH_OT_STRING,
+     .unwanted_positional = true,
      .help = N_("the backing volume if taking a snapshot")
     },
     {.name = "backing-vol-format",
      .type = VSH_OT_STRING,
+     .unwanted_positional = true,
      .help = N_("format of backing volume if taking a snapshot")
     },
     {.name = "prealloc-metadata",
@@ -245,10 +249,10 @@ cmdVolCreateAs(vshControl *ctl, const vshCmd *cmd)
     if (!(pool = virshCommandOptPool(ctl, cmd, "pool", NULL)))
         return false;
 
-    if (vshCommandOptStringReq(ctl, cmd, "name", &name) < 0)
+    if (vshCommandOptString(ctl, cmd, "name", &name) < 0)
         return false;
 
-    if (vshCommandOptStringReq(ctl, cmd, "capacity", &capacityStr) < 0)
+    if (vshCommandOptString(ctl, cmd, "capacity", &capacityStr) < 0)
         return false;
 
     if (virshVolSize(capacityStr, &capacity) < 0) {
@@ -262,10 +266,9 @@ cmdVolCreateAs(vshControl *ctl, const vshCmd *cmd)
         return false;
     }
 
-    if (vshCommandOptStringReq(ctl, cmd, "format", &format) < 0 ||
-        vshCommandOptStringReq(ctl, cmd, "backing-vol", &snapshotStrVol) < 0 ||
-        vshCommandOptStringReq(ctl, cmd, "backing-vol-format",
-                               &snapshotStrFormat) < 0)
+    if (vshCommandOptString(ctl, cmd, "format", &format) < 0 ||
+        vshCommandOptString(ctl, cmd, "backing-vol", &snapshotStrVol) < 0 ||
+        vshCommandOptString(ctl, cmd, "backing-vol-format", &snapshotStrFormat) < 0)
         return false;
 
     virBufferAddLit(&buf, "<volume>\n");
@@ -363,14 +366,9 @@ cmdVolCreateAs(vshControl *ctl, const vshCmd *cmd)
 /*
  * "vol-create" command
  */
-static const vshCmdInfo info_vol_create[] = {
-    {.name = "help",
-     .data = N_("create a vol from an XML file")
-    },
-    {.name = "desc",
-     .data = N_("Create a vol.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_create = {
+    .help = N_("create a vol from an XML file"),
+    .desc = N_("Create a vol."),
 };
 
 static const vshCmdOptDef opts_vol_create[] = {
@@ -405,7 +403,7 @@ cmdVolCreate(vshControl *ctl, const vshCmd *cmd)
     if (!(pool = virshCommandOptPool(ctl, cmd, "pool", NULL)))
         return false;
 
-    if (vshCommandOptStringReq(ctl, cmd, "file", &from) < 0)
+    if (vshCommandOptString(ctl, cmd, "file", &from) < 0)
         return false;
 
     if (virFileReadAll(from, VSH_MAX_XML_FILE, &buffer) < 0) {
@@ -426,14 +424,9 @@ cmdVolCreate(vshControl *ctl, const vshCmd *cmd)
 /*
  * "vol-create-from" command
  */
-static const vshCmdInfo info_vol_create_from[] = {
-    {.name = "help",
-     .data = N_("create a vol, using another volume as input")
-    },
-    {.name = "desc",
-     .data = N_("Create a vol from an existing volume.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_create_from = {
+    .help = N_("create a vol, using another volume as input"),
+    .desc = N_("Create a vol from an existing volume."),
 };
 
 static const vshCmdOptDef opts_vol_create_from[] = {
@@ -442,6 +435,7 @@ static const vshCmdOptDef opts_vol_create_from[] = {
     VIRSH_COMMON_OPT_VOL_FULL,
     {.name = "inputpool",
      .type = VSH_OT_STRING,
+     .unwanted_positional = true,
      .completer = virshStoragePoolNameCompleter,
      .help = N_("pool name or uuid of the input volume's pool")
     },
@@ -482,7 +476,7 @@ cmdVolCreateFrom(vshControl *ctl, const vshCmd *cmd)
     if (vshCommandOptBool(cmd, "validate"))
         flags |= VIR_STORAGE_VOL_CREATE_VALIDATE;
 
-    if (vshCommandOptStringReq(ctl, cmd, "file", &from) < 0)
+    if (vshCommandOptString(ctl, cmd, "file", &from) < 0)
         return false;
 
     if (!(inputvol = virshCommandOptVol(ctl, cmd, "vol", "inputpool", NULL)))
@@ -526,21 +520,17 @@ virshMakeCloneXML(const char *origxml, const char *newname)
 /*
  * "vol-clone" command
  */
-static const vshCmdInfo info_vol_clone[] = {
-    {.name = "help",
-     .data = N_("clone a volume.")
-    },
-    {.name = "desc",
-     .data = N_("Clone an existing volume within the parent pool.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_clone = {
+    .help = N_("clone a volume."),
+    .desc = N_("Clone an existing volume within the parent pool."),
 };
 
 static const vshCmdOptDef opts_vol_clone[] = {
     VIRSH_COMMON_OPT_VOL_FULL,
     {.name = "newname",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .completer = virshCompleteEmpty,
      .help = N_("clone name")
     },
@@ -586,7 +576,7 @@ cmdVolClone(vshControl *ctl, const vshCmd *cmd)
         return false;
     }
 
-    if (vshCommandOptStringReq(ctl, cmd, "newname", &name) < 0)
+    if (vshCommandOptString(ctl, cmd, "newname", &name) < 0)
         return false;
 
     if (!(origxml = virStorageVolGetXMLDesc(origvol, 0)))
@@ -616,14 +606,9 @@ cmdVolClone(vshControl *ctl, const vshCmd *cmd)
 /*
  * "vol-upload" command
  */
-static const vshCmdInfo info_vol_upload[] = {
-    {.name = "help",
-     .data = N_("upload file contents to a volume")
-    },
-    {.name = "desc",
-     .data = N_("Upload file contents to a volume")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_upload = {
+    .help = N_("upload file contents to a volume"),
+    .desc = N_("Upload file contents to a volume"),
 };
 
 static const vshCmdOptDef opts_vol_upload[] = {
@@ -632,10 +617,12 @@ static const vshCmdOptDef opts_vol_upload[] = {
     VIRSH_COMMON_OPT_POOL_OPTIONAL,
     {.name = "offset",
      .type = VSH_OT_INT,
+     .unwanted_positional = true,
      .help = N_("volume offset to upload to")
     },
     {.name = "length",
      .type = VSH_OT_INT,
+     .unwanted_positional = true,
      .help = N_("amount of data to upload")
     },
     {.name = "sparse",
@@ -668,7 +655,7 @@ cmdVolUpload(vshControl *ctl, const vshCmd *cmd)
     if (!(vol = virshCommandOptVol(ctl, cmd, "vol", "pool", &name)))
         return false;
 
-    if (vshCommandOptStringReq(ctl, cmd, "file", &file) < 0)
+    if (vshCommandOptString(ctl, cmd, "file", &file) < 0)
         return false;
 
     if ((fd = open(file, O_RDONLY)) < 0) {
@@ -729,14 +716,9 @@ cmdVolUpload(vshControl *ctl, const vshCmd *cmd)
 /*
  * "vol-download" command
  */
-static const vshCmdInfo info_vol_download[] = {
-    {.name = "help",
-     .data = N_("download volume contents to a file")
-    },
-    {.name = "desc",
-     .data = N_("Download volume contents to a file")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_download = {
+    .help = N_("download volume contents to a file"),
+    .desc = N_("Download volume contents to a file"),
 };
 
 static const vshCmdOptDef opts_vol_download[] = {
@@ -745,10 +727,12 @@ static const vshCmdOptDef opts_vol_download[] = {
     VIRSH_COMMON_OPT_POOL_OPTIONAL,
     {.name = "offset",
      .type = VSH_OT_INT,
+     .unwanted_positional = true,
      .help = N_("volume offset to download from")
     },
     {.name = "length",
      .type = VSH_OT_INT,
+     .unwanted_positional = true,
      .help = N_("amount of data to download")
     },
     {.name = "sparse",
@@ -783,7 +767,7 @@ cmdVolDownload(vshControl *ctl, const vshCmd *cmd)
     if (!(vol = virshCommandOptVol(ctl, cmd, "vol", "pool", &name)))
         return false;
 
-    if (vshCommandOptStringReq(ctl, cmd, "file", &file) < 0)
+    if (vshCommandOptString(ctl, cmd, "file", &file) < 0)
         goto cleanup;
 
     if (vshCommandOptBool(cmd, "sparse"))
@@ -845,14 +829,9 @@ cmdVolDownload(vshControl *ctl, const vshCmd *cmd)
 /*
  * "vol-delete" command
  */
-static const vshCmdInfo info_vol_delete[] = {
-    {.name = "help",
-     .data = N_("delete a vol")
-    },
-    {.name = "desc",
-     .data = N_("Delete a given vol.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_delete = {
+    .help = N_("delete a vol"),
+    .desc = N_("Delete a given vol."),
 };
 
 static const vshCmdOptDef opts_vol_delete[] = {
@@ -894,14 +873,9 @@ cmdVolDelete(vshControl *ctl, const vshCmd *cmd)
 /*
  * "vol-wipe" command
  */
-static const vshCmdInfo info_vol_wipe[] = {
-    {.name = "help",
-     .data = N_("wipe a vol")
-    },
-    {.name = "desc",
-     .data = N_("Ensure data previously on a volume is not accessible to future reads")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_wipe = {
+    .help = N_("wipe a vol"),
+    .desc = N_("Ensure data previously on a volume is not accessible to future reads"),
 };
 
 static const vshCmdOptDef opts_vol_wipe[] = {
@@ -909,6 +883,7 @@ static const vshCmdOptDef opts_vol_wipe[] = {
     VIRSH_COMMON_OPT_POOL_OPTIONAL,
     {.name = "algorithm",
      .type = VSH_OT_STRING,
+     .unwanted_positional = true,
      .completer = virshStorageVolWipeAlgorithmCompleter,
      .help = N_("perform selected wiping algorithm")
     },
@@ -932,7 +907,7 @@ cmdVolWipe(vshControl *ctl, const vshCmd *cmd)
     if (!(vol = virshCommandOptVol(ctl, cmd, "vol", "pool", &name)))
         return false;
 
-    if (vshCommandOptStringReq(ctl, cmd, "algorithm", &algorithm_str) < 0)
+    if (vshCommandOptString(ctl, cmd, "algorithm", &algorithm_str) < 0)
         return false;
 
     if (algorithm_str &&
@@ -978,14 +953,9 @@ virshVolumeTypeToString(int type)
 /*
  * "vol-info" command
  */
-static const vshCmdInfo info_vol_info[] = {
-    {.name = "help",
-     .data = N_("storage vol information")
-    },
-    {.name = "desc",
-     .data = N_("Returns basic information about the storage vol.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_info = {
+    .help = N_("storage vol information"),
+    .desc = N_("Returns basic information about the storage vol."),
 };
 
 static const vshCmdOptDef opts_vol_info[] = {
@@ -1058,23 +1028,19 @@ cmdVolInfo(vshControl *ctl, const vshCmd *cmd)
 /*
  * "vol-resize" command
  */
-static const vshCmdInfo info_vol_resize[] = {
-    {.name = "help",
-     .data = N_("resize a vol")
-    },
-    {.name = "desc",
-     .data = N_("Resizes a storage volume. This is safe only for storage "
+static const vshCmdInfo info_vol_resize = {
+     .help = N_("resize a vol"),
+     .desc = N_("Resizes a storage volume. This is safe only for storage "
                 "volumes not in use by an active guest.\n"
-                "See blockresize for live resizing.")
-    },
-    {.name = NULL}
+                "See blockresize for live resizing."),
 };
 
 static const vshCmdOptDef opts_vol_resize[] = {
     VIRSH_COMMON_OPT_VOL_FULL,
     {.name = "capacity",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .completer = virshCompleteEmpty,
      .help = N_("new capacity for the vol, as scaled integer (default bytes)")
     },
@@ -1111,7 +1077,7 @@ cmdVolResize(vshControl *ctl, const vshCmd *cmd)
     if (!(vol = virshCommandOptVol(ctl, cmd, "vol", "pool", NULL)))
         return false;
 
-    if (vshCommandOptStringReq(ctl, cmd, "capacity", &capacityStr) < 0)
+    if (vshCommandOptString(ctl, cmd, "capacity", &capacityStr) < 0)
         return false;
     virSkipSpaces(&capacityStr);
     if (*capacityStr == '-') {
@@ -1153,14 +1119,9 @@ cmdVolResize(vshControl *ctl, const vshCmd *cmd)
 /*
  * "vol-dumpxml" command
  */
-static const vshCmdInfo info_vol_dumpxml[] = {
-    {.name = "help",
-     .data = N_("vol information in XML")
-    },
-    {.name = "desc",
-     .data = N_("Output the vol information as an XML dump to stdout.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_dumpxml = {
+    .help = N_("vol information in XML"),
+    .desc = N_("Output the vol information as an XML dump to stdout."),
 };
 
 static const vshCmdOptDef opts_vol_dumpxml[] = {
@@ -1168,7 +1129,6 @@ static const vshCmdOptDef opts_vol_dumpxml[] = {
     VIRSH_COMMON_OPT_POOL_OPTIONAL,
     {.name = "xpath",
      .type = VSH_OT_STRING,
-     .flags = VSH_OFLAG_REQ_OPT,
      .completer = virshCompleteEmpty,
      .help = N_("xpath expression to filter the XML document")
     },
@@ -1327,14 +1287,9 @@ virshStorageVolListCollect(vshControl *ctl,
 /*
  * "vol-list" command
  */
-static const vshCmdInfo info_vol_list[] = {
-    {.name = "help",
-     .data = N_("list vols")
-    },
-    {.name = "desc",
-     .data = N_("Returns list of vols by pool.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_list = {
+    .help = N_("list vols"),
+    .desc = N_("Returns list of vols by pool."),
 };
 
 static const vshCmdOptDef opts_vol_list[] = {
@@ -1485,14 +1440,9 @@ cmdVolList(vshControl *ctl, const vshCmd *cmd G_GNUC_UNUSED)
 /*
  * "vol-name" command
  */
-static const vshCmdInfo info_vol_name[] = {
-    {.name = "help",
-     .data = N_("returns the volume name for a given volume key or path")
-    },
-    {.name = "desc",
-     .data = ""
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_name = {
+    .help = N_("returns the volume name for a given volume key or path"),
+    .desc = "",
 };
 
 static const vshCmdOptDef opts_vol_name[] = {
@@ -1516,14 +1466,9 @@ cmdVolName(vshControl *ctl, const vshCmd *cmd)
 /*
  * "vol-pool" command
  */
-static const vshCmdInfo info_vol_pool[] = {
-    {.name = "help",
-     .data = N_("returns the storage pool for a given volume key or path")
-    },
-    {.name = "desc",
-     .data = ""
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_pool = {
+    .help = N_("returns the storage pool for a given volume key or path"),
+    .desc = "",
 };
 
 static const vshCmdOptDef opts_vol_pool[] = {
@@ -1571,14 +1516,9 @@ cmdVolPool(vshControl *ctl, const vshCmd *cmd)
 /*
  * "vol-key" command
  */
-static const vshCmdInfo info_vol_key[] = {
-    {.name = "help",
-     .data = N_("returns the volume key for a given volume name or path")
-    },
-    {.name = "desc",
-     .data = ""
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_key = {
+    .help = N_("returns the volume key for a given volume name or path"),
+    .desc = "",
 };
 
 static const vshCmdOptDef opts_vol_key[] = {
@@ -1602,14 +1542,9 @@ cmdVolKey(vshControl *ctl, const vshCmd *cmd)
 /*
  * "vol-path" command
  */
-static const vshCmdInfo info_vol_path[] = {
-    {.name = "help",
-     .data = N_("returns the volume path for a given volume name or key")
-    },
-    {.name = "desc",
-     .data = ""
-    },
-    {.name = NULL}
+static const vshCmdInfo info_vol_path = {
+    .help = N_("returns the volume path for a given volume name or key"),
+    .desc = "",
 };
 
 static const vshCmdOptDef opts_vol_path[] = {
@@ -1639,97 +1574,97 @@ const vshCmdDef storageVolCmds[] = {
     {.name = "vol-clone",
      .handler = cmdVolClone,
      .opts = opts_vol_clone,
-     .info = info_vol_clone,
+     .info = &info_vol_clone,
      .flags = 0
     },
     {.name = "vol-create-as",
      .handler = cmdVolCreateAs,
      .opts = opts_vol_create_as,
-     .info = info_vol_create_as,
+     .info = &info_vol_create_as,
      .flags = 0
     },
     {.name = "vol-create",
      .handler = cmdVolCreate,
      .opts = opts_vol_create,
-     .info = info_vol_create,
+     .info = &info_vol_create,
      .flags = 0
     },
     {.name = "vol-create-from",
      .handler = cmdVolCreateFrom,
      .opts = opts_vol_create_from,
-     .info = info_vol_create_from,
+     .info = &info_vol_create_from,
      .flags = 0
     },
     {.name = "vol-delete",
      .handler = cmdVolDelete,
      .opts = opts_vol_delete,
-     .info = info_vol_delete,
+     .info = &info_vol_delete,
      .flags = 0
     },
     {.name = "vol-download",
      .handler = cmdVolDownload,
      .opts = opts_vol_download,
-     .info = info_vol_download,
+     .info = &info_vol_download,
      .flags = 0
     },
     {.name = "vol-dumpxml",
      .handler = cmdVolDumpXML,
      .opts = opts_vol_dumpxml,
-     .info = info_vol_dumpxml,
+     .info = &info_vol_dumpxml,
      .flags = 0
     },
     {.name = "vol-info",
      .handler = cmdVolInfo,
      .opts = opts_vol_info,
-     .info = info_vol_info,
+     .info = &info_vol_info,
      .flags = 0
     },
     {.name = "vol-key",
      .handler = cmdVolKey,
      .opts = opts_vol_key,
-     .info = info_vol_key,
+     .info = &info_vol_key,
      .flags = 0
     },
     {.name = "vol-list",
      .handler = cmdVolList,
      .opts = opts_vol_list,
-     .info = info_vol_list,
+     .info = &info_vol_list,
      .flags = 0
     },
     {.name = "vol-name",
      .handler = cmdVolName,
      .opts = opts_vol_name,
-     .info = info_vol_name,
+     .info = &info_vol_name,
      .flags = 0
     },
     {.name = "vol-path",
      .handler = cmdVolPath,
      .opts = opts_vol_path,
-     .info = info_vol_path,
+     .info = &info_vol_path,
      .flags = 0
     },
     {.name = "vol-pool",
      .handler = cmdVolPool,
      .opts = opts_vol_pool,
-     .info = info_vol_pool,
+     .info = &info_vol_pool,
      .flags = 0
     },
     {.name = "vol-resize",
      .handler = cmdVolResize,
      .opts = opts_vol_resize,
-     .info = info_vol_resize,
+     .info = &info_vol_resize,
      .flags = 0
     },
     {.name = "vol-upload",
      .handler = cmdVolUpload,
      .opts = opts_vol_upload,
-     .info = info_vol_upload,
+     .info = &info_vol_upload,
      .flags = 0
     },
     {.name = "vol-wipe",
      .handler = cmdVolWipe,
      .opts = opts_vol_wipe,
-     .info = info_vol_wipe,
+     .info = &info_vol_wipe,
      .flags = 0
     },
     {.name = NULL}
