@@ -24,14 +24,7 @@
 #include "internal.h"
 #include "virbitmap.h"
 #include "virenum.h"
-
-typedef enum {
-    VIR_HOST_VALIDATE_FAIL,
-    VIR_HOST_VALIDATE_WARN,
-    VIR_HOST_VALIDATE_NOTE,
-
-    VIR_HOST_VALIDATE_LAST,
-} virHostValidateLevel;
+#include "virt-validate-common.h"
 
 typedef enum {
     VIR_HOST_VALIDATE_CPU_FLAG_VMX = 0,
@@ -45,61 +38,36 @@ typedef enum {
 
 VIR_ENUM_DECL(virHostValidateCPUFlag);
 
-/**
- * VIR_HOST_VALIDATE_FAILURE
- * @level: the virHostValidateLevel to be checked
- *
- * This macro is to be used in to return a failures based on the
- * virHostValidateLevel use in the function.
- *
- * If the virHostValidateLevel is VIR_HOST_VALIDATE_FAIL, -1 is returned.
- * 0 is returned otherwise (as the virHosValidateLevel is then either a
- * Warn or a Note).
- */
-
-#define VIR_HOST_VALIDATE_FAILURE(level) (level == VIR_HOST_VALIDATE_FAIL) ? -1 : 0
-
-void virHostMsgSetQuiet(bool quietFlag);
-
-void virHostMsgCheck(const char *prefix,
-                     const char *format,
-                     ...) G_GNUC_PRINTF(2, 3);
-
-void virHostMsgPass(void);
-void virHostMsgFail(virHostValidateLevel level,
-                    const char *format,
-                    ...) G_GNUC_PRINTF(2, 3);
-
 int virHostValidateDeviceExists(const char *hvname,
                                 const char *dev_name,
-                                virHostValidateLevel level,
+                                virValidateLevel level,
                                 const char *hint);
 
 int virHostValidateDeviceAccessible(const char *hvname,
                                     const char *dev_name,
-                                    virHostValidateLevel level,
+                                    virValidateLevel level,
                                     const char *hint);
 
 virBitmap *virHostValidateGetCPUFlags(void);
 
 int virHostValidateLinuxKernel(const char *hvname,
                                int version,
-                               virHostValidateLevel level,
+                               virValidateLevel level,
                                const char *hint);
 
 int virHostValidateNamespace(const char *hvname,
                              const char *ns_name,
-                             virHostValidateLevel level,
+                             virValidateLevel level,
                              const char *hint);
 
 int virHostValidateCGroupControllers(const char *hvname,
                                      int controllers,
-                                     virHostValidateLevel level);
+                                     virValidateLevel level);
 
 int virHostValidateIOMMU(const char *hvname,
-                         virHostValidateLevel level);
+                         virValidateLevel level);
 
 int virHostValidateSecureGuests(const char *hvname,
-                                virHostValidateLevel level);
+                                virValidateLevel level);
 
 bool virHostKernelModuleIsLoaded(const char *module);
